#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-FgyxzsyRioh7GnBwcGBw8N
key:                  regex-compat-tdfa-0.95.1.4-FgyxzsyRioh7GnBwcGBw8N
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  e13ea9e2e499b6f5362c68c293f21ba7
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-compat-tdfa-0.95.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-FgyxzsyRioh7GnBwcGBw8N
depends:
    array-0.5.6.0 base-4.18.2.1
    regex-base-0.94.0.3-6fVrfocUW2t4u08iX8Rj6b
    regex-tdfa-1.3.2.5-6WzoC7SgjRyHxrF8NwW4mF

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

